@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 1998-2011 Peter Miller
+// Copyright (C) 1998-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -147,6 +147,7 @@ public:
         token_over,
         token_paren_begin,
         token_paren_end,
+        token_polynomial,
         token_ppb,
         token_ppx,
         token_ram,
@@ -172,6 +173,8 @@ public:
         token_spectrum,
         token_split,
         token_stewie,
+        token_stm32_crc_be,
+        token_stm32_crc_le,
         token_style_dot,
         token_style_hexadecimal,
         token_style_hexadecimal_not,
@@ -182,6 +185,7 @@ public:
         token_ti_tagged,
         token_ti_tagged_16,
         token_ti_txt,
+        token_trs80,
         token_unfill,
         token_union,
         token_unsplit,
@@ -450,4 +454,5 @@ private:
 
 };
 
+// vim: set ts=8 sw=4 et :
 #endif // SRECORD_ARGLEX_TOOL_H
