@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2001-2003, 2005-2008, 2010, 2011 Peter Miller
+// Copyright (C) 2001-2003, 2005-2008, 2010-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -71,7 +71,7 @@ srecord::input_file_emon52::read(srecord::record &record)
     if (length == 0)
         fatal_error("data length of zero is not valid");
     skip_white_space();
-    unsigned long address = get_word();
+    unsigned long address = get_word_be();
     if (get_char() != ':')
         fatal_error("colon expected");
     checksum_reset();
@@ -83,7 +83,7 @@ srecord::input_file_emon52::read(srecord::record &record)
     }
     skip_white_space();
     int csumX = checksum_get16();
-    int csum = get_word();
+    int csum = get_word_be();
     if (use_checksums() && csumX != csum)
         fatal_error("checksum mismatch (%04X != %04X)", csumX, csum);
     if (get_char() != '\n')
