@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2003, 2005-2008, 2010, 2011 Peter Miller
+// Copyright (C) 2003, 2005-2008, 2010-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -103,7 +103,7 @@ srecord::input_file_fairchild::read(record &result)
             return false;
 
         case 'S':
-            address = get_word();
+            address = get_word_be();
             break;
 
         case 'X':
