@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2000-2011 Peter Miller
+// Copyright (C) 2000-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -52,6 +52,7 @@
 #include <srecord/input/file/tektronix_extended.h>
 #include <srecord/input/file/ti_tagged.h>
 #include <srecord/input/file/ti_txt.h>
+#include <srecord/input/file/trs80.h>
 #include <srecord/input/file/vmem.h>
 #include <srecord/input/file/wilson.h>
 #include <srecord/record.h>
@@ -78,7 +79,6 @@ static func_p table[] =
     srecord::input_file_mips_flash::create_be,
     srecord::input_file_mos_tech::create,
     srecord::input_file_motorola::create,
-    srecord::input_file_msbin::create,
     srecord::input_file_needham::create,
     srecord::input_file_os65v::create,
     srecord::input_file_ppb::create,
@@ -91,6 +91,8 @@ static func_p table[] =
     srecord::input_file_tektronix_extended::create,
     srecord::input_file_ti_tagged::create,
     srecord::input_file_ti_txt::create,
+    srecord::input_file_trs80::create,
+    srecord::input_file_msbin::create, // test after trs80
     srecord::input_file_vmem::create,
     srecord::input_file_wilson::create,
     srecord::input_file_hexdump::create,
