@@ -1,6 +1,6 @@
 //
 // srecord - manipulate eprom load files
-// Copyright (C) 2001-2003, 2005-2008, 2010, 2011 Peter Miller
+// Copyright (C) 2001-2003, 2005-2008, 2010-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -78,7 +78,7 @@ srecord::input_file_signetics::read_inner(srecord::record &record)
         }
     }
     checksum_reset();
-    long address = get_word();
+    long address = get_word_be();
     int length = get_byte();
     if (length == 0)
     {
