@@ -1,6 +1,6 @@
 //
 // srecord - Manipulate EPROM load files
-// Copyright (C) 2010, 2011 Peter Miller
+// Copyright (C) 2010-2012 Peter Miller
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published by
@@ -54,6 +54,7 @@
 #include <srecord/input/file/ti_tagged.h>
 #include <srecord/input/file/ti_tagged_16.h>
 #include <srecord/input/file/ti_txt.h>
+#include <srecord/input/file/trs80.h>
 #include <srecord/input/file/vmem.h>
 #include <srecord/input/file/wilson.h>
 #include <srecord/input/filter.h>
@@ -137,6 +138,7 @@
 #include <srecord/output/file/ti_tagged.h>
 #include <srecord/output/file/ti_tagged_16.h>
 #include <srecord/output/file/ti_txt.h>
+#include <srecord/output/file/trs80.h>
 #include <srecord/output/file/vhdl.h>
 #include <srecord/output/file/vmem.h>
 #include <srecord/output/file/wilson.h>
